summaryrefslogtreecommitdiff
path: root/sys/dev/ic/am7990.c
diff options
context:
space:
mode:
authorBrad Smith <brad@cvs.openbsd.org>2005-11-07 03:20:01 +0000
committerBrad Smith <brad@cvs.openbsd.org>2005-11-07 03:20:01 +0000
commita7f3467c88281b875f60021303fe31ca7fb2dff8 (patch)
treeb0e95e1dc2fc33ad1fb41a37bf402c39d0bf19ba /sys/dev/ic/am7990.c
parent122c6d25289aaf1ae44207930b4b0660a098558c (diff)
splimp -> splnet
Diffstat (limited to 'sys/dev/ic/am7990.c')
-rw-r--r--sys/dev/ic/am7990.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/ic/am7990.c b/sys/dev/ic/am7990.c
index 8447a7aa1a6..3ed233a2a5e 100644
--- a/sys/dev/ic/am7990.c
+++ b/sys/dev/ic/am7990.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: am7990.c,v 1.38 2005/01/15 05:24:10 brad Exp $ */
+/* $OpenBSD: am7990.c,v 1.39 2005/11/07 03:20:00 brad Exp $ */
/* $NetBSD: am7990.c,v 1.22 1996/10/13 01:37:19 christos Exp $ */
/*-
@@ -215,7 +215,7 @@ am7990_reset(sc)
{
int s;
- s = splimp();
+ s = splnet();
am7990_init(sc);
splx(s);
}
@@ -742,7 +742,7 @@ am7990_watchdog(ifp)
* Setup output on interface.
* Get another datagram to send off of the interface queue, and map it to the
* interface before starting the output.
* Called only at splimp or interrupt level.
*/
void
am7990_start(ifp)
@@ -841,7 +841,7 @@ am7990_ioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
if ((error = ether_ioctl(ifp, &sc->sc_arpcom, cmd, data)) > 0) {
splx(s);
@@ -742,7 +742,7 @@ am7990_watchdog(ifp)
* Get another datagram to send off of the interface queue, and map it to the
* interface before starting the output.
- * Called only at splimp or interrupt level.
+ * Called only at splnet or interrupt level.
*/
void